local AddOn, NS = ...

local NewParent = CreateFrame("Frame")
NewParent.unit = "player"
NewParent:Hide()

local function GetFrame(frame)
	local f
	if type(frame) == "string" then
		f = _G[frame]
	elseif type(frame) == "table" then
		f = frame
	else
	end
	return f
end

local  function DoUnhook(frame)
	frame:SetParent(NewParent)
	UnregisterUnitWatch(frame)
	frame:UnregisterAllEvents()
	frame:SetScript("OnUpdate", nil)
	frame:SetScript("OnEvent", nil)
	if not InCombatLockdown() then
		frame:Hide()
	end
--	frame:ClearAllPoints()
--	frame:SetPoint("BOTTOMLEFT", UIParent, "TOPLEFT", -400, 500)
end

local function UnhookFrame(frame)
	local f = GetFrame(frame)
	if not f then
		return
	end
	DoUnhook(f)
	for i=1, select("#", f:GetChildren()) do
		UnhookFrame(select(i, f:GetChildren()))
	end
	local healthbar = frame.healthbar
	if healthbar then
		healthbar:UnregisterAllEvents()
		healthbar:SetParent(NewParent)
	end
	local manabar = frame.manabar
	if manabar then
		manabar:UnregisterAllEvents()
		manabar:SetParent(NewParent)
	end
	local powerBarAlt = frame.powerBarAlt
	if powerBarAlt then
		powerBarAlt:UnregisterAllEvents()
		powerBarAlt:SetParent(NewParent)
	end
	local spellbar = frame.spellbar
	if spellbar then
		spellbar:UnregisterAllEvents()
		spellbar:SetParent(NewParent)
	end
	local buffFrame = frame.BuffFrame
	if buffFrame then
		buffFrame:UnregisterAllEvents()
		buffFrame:SetParent(NewParent)
	end
	local petFrame = frame.petFrame or frame.PetFrame
	if petFrame then
		petFrame:UnregisterAllEvents()
		petFrame:SetParent(NewParent)
	end
end

function NS:DUF_SetDefaultUIHooks()
	if not DUF_Settings[DUF_INDEX].player.showDefault then
		if PlayerFrameAlternateManaBar then
			UnhookFrame(PlayerFrameAlternateManaBar)
		end
		if MonkStaggerBar then
			UnhookFrame(MonkStaggerBar)
		end
		UnhookFrame(PlayerFrame)
		if PlayerFrameTexture then -- Dragonflight change
			PlayerFrameTexture:ClearAllPoints()
			PlayerFrameTexture:SetPoint("BOTTOMRIGHT", UIParent, "TOPLEFT", -50, 50)
		end
		UnhookFrame(ComboFrame)
		UnhookFrame(ComboPointPlayerFrame)
		UnhookFrame(TargetofFocusFrame)
		UnhookFrame(TargetFrameToT)
		UnhookFrame(InsanityBarFrame)
		UnhookFrame(MageArcaneChargesFrame)
		UnhookFrame(MonkHarmonyBarFrame)
		UnhookFrame(PaladinPowerBarFrame)
		UnhookFrame(WarlockPowerFrame)
		UnhookFrame(MonkStaggerBar)
		UnhookFrame(EssencePlayerFrameTemplate)
	else
	end
	if DUF_Settings[DUF_INDEX].hidedurability then 
		UnhookFrame(DurabilityFrame)
	end
	if not DUF_Settings[DUF_INDEX].focus.showDefault then
		UnhookFrame(FocusFrame)
	end
	if not DUF_Settings[DUF_INDEX].targettarget.showDefault then
		UnhookFrame(TargetofTargetFrame)
	end
	if not DUF_Settings[DUF_INDEX].target.showDefault then
		UnhookFrame(TargetFrame)
	end
	if not DUF_Settings[DUF_INDEX].pet.showDefault then
		UnhookFrame(PetFrame)
		UnhookFrame(PetCastingBarFrame)
	end
	if not DUF_Settings[DUF_INDEX].party.showDefault then
		if PartyFrame and PartyFrame.PartyMemberFramePool then
			UnhookFrame(PartyFrame)
			for memberFrame in PartyFrame.PartyMemberFramePool:EnumerateActive() do
				UnhookFrame(memberFrame)
				memberFrame.HealthBar:SetScript("OnValueChanged", nil)
			end
		else
			for i = 1, 4 do
				UnhookFrame(_G["PartyMemberFrame"..i])
			end
		end
	end
	if not DUF_Settings[DUF_INDEX].partypet.showDefault then
		if PartyFrame and PartyFrame.PartyMemberFramePool then
			for memberFrame in PartyFrame.PartyMemberFramePool:EnumerateActive() do
				UnhookFrame(memberFrame.PetFrame)
				memberFrame.HealthBar:SetScript("OnValueChanged", nil)
			end
		else
			for i = 1, 4 do
				UnhookFrame(_G["PartyMemberFrame"..i.."PetFrame"])
			end
		end
	end
	if Boss1TargetFrame then
		if not DUF_Settings[DUF_INDEX].boss.showDefault then
			for i = 1, 5 do
				UnhookFrame(_G["Boss"..i.."TargetFrame"], true)
			end
		end
	else
		for i=1, 5 do
			local f = _G["DUF_BossFrame"..i]
			UnhookFrame(f)
			f:Hide()
		end
	end
	if not FocusFrame then
		UnhookFrame(DUF_FocusFrame)
	end
end
